<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Acerca de </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Contacto</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licencia: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Herramienta de Captura de Pantalla y Anotación</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Atajo</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Tomar captura</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Incluir cursor</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Retrasar</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Modo de captura</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Mostrar imagen en la ventana de alfiler</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Copiar imagen al portapapeles</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Cargar imagen</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Abrir directorio principal de imágenes</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Guardar imagen</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Ocultar la Ventana Principal</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Configuración de acciones</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Imagen de marca de agua requerida</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Agrega una Imagen de Marca de Agua via Opciones &gt; Configuracion &gt; Anotador &gt; Actualizar</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Suavizar Rutas del dibujo</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Cuando está habilitado, suavizar pluma y
trazados de marcador al terminar de dibujar.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Factor del suavizado</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Aumentar el factor del suavizado, disminuirá
precisión para lápiz y marcador, los hará
más suaves.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Ajustes del anotador</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Recordar herramienta de selección y cargarla al iniciar</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Cambiar a Selección de Herramienta después de dibujar Item</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Al seleccionar un modo diferente en la herramienta numérica se actualizan todos los elementos numéricos</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>La desactivación de esta opción provoca cambios en la simiente de la herramienta numérica
para afectar solo a los elementos nuevos, pero no a los existentes.
Desactivar esta opción permite tener números duplicados.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Color del lienzo</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Color de fondo del lienzo predeterminado para el área de anotaciones.
El cambio de color afecta solo a las áreas de anotación nuevas.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Seleccionar Elemento tras dibujar</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Con esta opción seleccionada, los elementos se seleccionan
después de ser creados, permitiendo cambiar la configuración.</translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Captura de pantalla al inicio con el modo predeterminado</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Estilo de aplicación</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Establece el estilo de la aplicación que define la apariencia de la GUI
El cambio requiere el reinicio de ksnip para que tenga efecto.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Ajustes de la aplicación</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Copiar automáticamente al portapapeles las nuevas capturas</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Usar pestañas</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>El cambio requiere reiniciar.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Mantener ksnip como una única instancia al abrirla nuevamente</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Ocultar barra de pestañas solo cuando una pestaña está en uso.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Habilitando esta opción permitirá que solo una instancia de ksnip inicie,
el resto de las instancias iniciadas después pasarán sus
argumentos a la primera y se cerrarán. Cambiar esta opción requiere
un nuevo inicio de todas las instancias.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Al mover la ventana principal recordar la posición y restaurarla al iniciar</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Ocultar automáticamente las pestañas</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Ocultar automáticamente los Docks</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Al inicio ocultar la barra de herramientas y las opciones de comentarios.
Se puede alternar la visibilidad del Dock con el tabulador.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Cambiar de tamaño automáticamente al contenido</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Cambie automáticamente el tamaño de la ventana principal para que se ajuste a la imagen del contenido.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Activar depuración</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Activa la salida de depuración en consola.
Este cambio require reiniciar ksnip.</translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation type="unfinished">Redimensionar al retraso del contenido</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>Cambiar el tamaño al contenido es un retraso para permitir que el Administrador de ventanas reciba
el nuevo contenido. En caso de que la ventana principal no esté correctamente ajustada
al nuevo contenido, aumentar este retraso podría mejorar el comportamiento.</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Colaboradores:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Traducción al castellano</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Traducción al neerlandés</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Traducción al ruso</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Traducción al noruego «bokmål»</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Traducción al francés</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Traducción al polaco</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Compatibilidad con Snap y Flatpak</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Autores:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Advertencia - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>La captura %1%2%3 ha sido modificada
¿Desea guardar?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Dibuje un área rectangular con el ratón</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Capturar pantalla completa, incluidos todos los monitores</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Capturar pantalla donde se localiza el ratón</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Capturar ventana que actualmente tiene el foco</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Captura que se encuentra actualmente debajo del cursor del mouse</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Realiza una captura de pantalla de la última área rectangular seleccionada</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Usa el portal de capturas para tomar capturas</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Comunidad</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Reporte de errores</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Si tiene preguntas generales, ideas o simplemente quiere hablar sobre ksnip,&lt;br/&gt;únase a nuestro %1 o nuestro %2 servidor.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Utilice %1 para informar errores.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>No se pudo copiar al portapapeles</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>No se pudo copiar al portapapeles como imagen codificada en base64.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Copiado al portapapeles</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Copiado al portapapeles como imagen codificada en base64.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Eliminar imagen</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Se eliminará el elemento «%1».
¿Quiere continuar?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Las donaciones son siempre bienvenidas</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Donación</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip es un proyecto de software libre copyleft no rentable, y&lt;br/&gt;todavía tiene algunos costos que deben cubrirse,&lt;br/&gt;como costos de dominio o costos de hardware para el soporte multiplataforma.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Si desea ayudar o simplemente desea apreciar el trabajo que se está realizando&lt;br/&gt;invitando a los desarrolladores a tomar una cerveza o un café, puede hacerlo %1aquí%2.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>¿Convertirse en patrocinador de GitHub?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>También es posible, %1aquí%2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Agregue nuevas acciones presionando el botón de la pestaña &apos;Agregar&apos;.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Área rectangular</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Última área rectangular</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Pantalla completa (todos los monitores)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Pantalla actual</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Ventana activa</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Ventana bajo el puntero</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Portal de capturas</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Forzar subida anónima.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Clave</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Cargador FTP</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Subida con éxito</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Incapaz de guardar temporalmente la imagen para subir.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Incapaz de iniciar el proceso, revise la ruta y los permisos.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Proceso se cayó</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Proceso con tiempo de espera agotado.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Proceso con error de lectura.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Proceso con error de escritura.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Error Web, revise la salida en la consola.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Subida fallida</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>El script escribió en StdErr.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>Carga FTP finalizada con éxito.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Error desconocido.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Error de conexión.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Error de permiso.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>El script de carga %1 finalizó correctamente.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>Subido a %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Activar atajos de teclado globales</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Capturar área rectangular</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Capturar pantalla completa</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Capturar pantalla actual</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Capturar ventana activa</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Capturar ventana bajo el puntero</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Atajos de teclado globales</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Captura la última área rectangular</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Capturar mediante portal</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>Actualmente, las teclas de acceso rápido solo son compatibles con Windows y X11.
La desactivación de esta opción también hace que los atajos de acción sean solo en ksnip.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Capturar el cursor del ratón en la captura de pantalla</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>El cursor del mouse debe estar visible sobre
las capturas de pantalla.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Capturador de imágenes</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Implementaciones genéricas de Wayland que utilizan
Escalado de pantalla de control XDG-DESKTOP-PORTAL
diferentemente. Habilitar esta opción
determinar la escala de pantalla actual y
aplicar eso a la captura de pantalla en ksnip.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME y KDE Plasma admiten su propio Wayland
y las capturas de pantalla genéricas de XDG-DESKTOP-PORTAL.
Habilitar esta opción forzará KDE Plasma y
GNOME para usar las capturas de pantalla de XDG-DESKTOP-PORTAL.
El cambio en esta opción requiere un reinicio de ksnip.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Mostrar ventana principal después de una captura de pantalla</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Ocultar la ventana principal durante una captura de pantalla</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Ocultar la ventana principal al realizar una nueva captura de pantalla.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Mostrar ventana principal después de capturar una nueva captura de pantalla
cuando la ventana principal estaba oculta o minimizada.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Forzar Genérico Wayland (xdg-desktop-portal) Captura de pantalla</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Escala Genérica Wayland (xdg-desktop-portal) Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Historial Imgur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Cronomarcador</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Enlace</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Eliminar enlace</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Finalizó la carga en imgur.com.</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Se recibió una ficha nueva; reintentando la carga…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>La ficha de Imgur ha caducado; solicitando una nueva…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Forzar carga anónima</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Siempre copiar enlace de Imgur al portapapeles</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Id. de cliente</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Secreto de cliente</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Introduzca el PIN de Imgur, que se intercambiará por una ficha.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Obtener PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Obtener ficha</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Historial de Imgur</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Cargador de Imgur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Esperando a imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Se actualizó la ficha de Imgur.com correctamente.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Error de actualización de la ficha de Imgur.com.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Después de subir, abra el enlace de Imgur en el navegador predeterminado</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Enlazar directamente a la imagen</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>URL de base:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>El URL de base que se utilizará para la comunicación con Imgur.
Cambiarlo requiere reiniciar.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Limpiar Token</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>No se puede abrir la imagen</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>No se puede abrir la imagen de la ruta% 1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Demora en segundos entre la activación
y la captura de pantalla.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Guardar captura de pantalla en el sistema de archivos</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Copiar captura de pantalla en el portapapeles</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Recortar captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>No guardado</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Abre el cuadro de diálogo de la impresora y proporciona la opción para imprimir la imagen</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Previsualizar impresión</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Abre el cuadro de diálogo Previsualizar impresión, donde se puede cambiar la orientación de la imagen</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Escalar</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opciones</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Añadir marca de agua</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Añade la marca de agua a la imagen capturada. Se pueden añadir múltiples marcas de agua.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>No se puede mostrar la imagen</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Guardar como...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Pegar incrustado</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation type="unfinished">Anclar</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Fija la captura de pantalla al primer plano en una ventana sin marco</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>No se proporcionó ninguna imagen aunque se esperaba una.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Copiar ruta</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir directorio</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Abrir imagenes</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Mostrar muelles</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Esconder Docks</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Copiar como URI de datos</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Abierto &amp; reciente</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Modificar lienzo</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>Cargar captura de disparo a una fuente externa</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Copiar captura de disparador al portapapeles del sistema</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Escalar Imagen</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Girar</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Girar imagen</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished">Acciones</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Archivos de Imagen</translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir directorio</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Copiar ruta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Capturar</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Cerrar otros</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Cerrar todos</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>Fijar ventana %1</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Imagen renombrada</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Fallo al renombrar la imagen</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Renombrar imagen</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Nuevo nombre de archivo:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>Imagen renombrada correctamente a %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>Error al cambiar el nombre de la imagen a %1</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Todos los archivos</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Imagen guardada</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>No se pudo guardar la imagen</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Archivos de Imagen</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Salvado a %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>Error al guardar la imagen en %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Guardar automáticamente las capturas nuevas a la ubicación predeterminada</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Preguntar antes de descartar cambios no guardados</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Recordar última carpeta de guardado</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Cuando está habilitado, sobreescribe la última carpeta guardada en las configuraciones
con la última carpeta en donde se guarda, esto lo hace en cada guardado.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Captura la ubicación de guardado y el nombre del archivo</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Los formatos soportados son JPG, PNG and BMP. Si no se indica un formato, se usará PNG por defecto.
El nombre del archivo puede contener los siguientes comodines:
- $Y, $M, $D para la fecha, $h, $m, $s para la hora, or $T para hora en el formato hhmmss.
- Multiples consecutivos # para un correlativo. #### generará un 0001, siguiente captura será 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Examinar</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Configuraciones de guardado</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Ubicación de guardado de capturas</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Factor</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Calidad de guardado</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Defina 0 para obtener archivos pequeños y comprimidos o 100 para archivos
grandes y sin comprimir.
No todos los formatos de archivo admiten todo el intervalo; JPG lo hace.</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Copiar salida de la secuencia en el portapapeles</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Secuencia de órdenes:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Ruta a la secuencia que se llamará para la carga. Durante la carga la secuencia se
invocará con la ruta a un archivo PNG temporal como único argumento.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Examinar</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Cargador por secuencia</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Seleccione secuencia de carga</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Detener cuando la secuencia de carga escriba en la salida de errores estándar</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Marca la carga como fallida cuando el script escribe en StdErr.
Sin esta configuración, los errores en el script pasarán desapercibidos.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>Expresión RegEx. Solo copie al portapapeles lo que coincida con la expresión RegEx.
Cuando se omite, se copia todo.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Capturador de imágenes</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Cargador de Imgur</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplicación</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Anotador</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Atajos de teclado</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Cargador</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Cargar con secuencia</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Guardado</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Adhesivos</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Área de recorte</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Icono de bandeja</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Marca de Agua</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Acciones</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Cargador FTP</translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Cambie el tamaño del rectángulo seleccionado usando las manijas o muévalo arrastrando la selección.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Utilice las teclas de flecha para mover la selección.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Use las teclas de flecha mientras presiona CTRL para mover la manija superior izquierda.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Use las teclas de flecha mientras presiona ALT para mover la manija inferior derecha.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation>Confirme la selección presionando ENTER / RETURN o cancele presionando ESC.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Este mensaje se puede desactivar a través de la configuración.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Haga clic y arrastre para seleccionar un área rectangular o presione ESC para salir.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Mantenga presionada la tecla CTRL para cambiar el tamaño de la selección después de seleccionarla.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Mantenga presionada la tecla CTRL para evitar cambiar el tamaño después de seleccionar.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>La operación se cancelará después de 60 segundos cuando no se realice ninguna selección.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Este mensaje se puede desactivar a través de la configuración.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation type="unfinished">Congele la imagen mientras corta</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Cuando está habilitado, congelará el fondo mientras
seleccionando una región rectangular. También cambia
el comportamiento de las capturas de pantalla retrasadas, con esto
opción habilitada, el retraso ocurre antes de que
se muestra el área de recorte y con la opción desactivada
el retraso ocurre después de que se muestra el área de recorte.
Esta función siempre está desactivada para Wayland y siempre
habilitado para MacOs.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation type="unfinished">Mostrar lupa en el área de corte</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation type="unfinished">Muestra una lupa que se acerca a
la imagen de fondo. Esta opción solo funciona
con la opción &quot;Congelar la imagen mientras se corta&quot; activada.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation type="unfinished">Mostrar reglas del área de recorte</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation type="unfinished">Líneas horizontales y verticales que van desde
los bordes del escritorio al cursor en el área de corte.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation type="unfinished">Mostrar la posición del área de corte y la información del tamaño</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation type="unfinished">Color del área de corte del cursor</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation type="unfinished">Grosor del área de corte del cursor</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation type="unfinished">Área de recorte</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Color del recuadro de recorte</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Transparencia del area de recorte</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Utilizar adhesivos predeterminados</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Configuración de adhesivos</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Archivos de imagen vectorial (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Adicionar pegatina</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Mostrar editor</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation type="unfinished">Usa el icono de la bandeja</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation type="unfinished">Al activarse, añadirá un icono de bandeja a la barra de tareas si el administrador de ventanas del sistema operativo lo admite.
El cambio requiere que se reinicie.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation type="unfinished">Minimizar a la bandeja</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation type="unfinished">Iniciar minimizado en la bandeja</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation type="unfinished">Cierre a la Bandeja</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation type="unfinished">Mostrar editor</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation type="unfinished">Capturar</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Acción por defecto del icono de bandeja</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Acción por defecto de clic izquierdo en el icono de la bandeja</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Configuración del icono de bandeja</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Utilice el servicio de notificación específico de la plataforma</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Seleccionar imagen</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Se requiere la secuencia de carga</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Añada una secuencia de carga en Opciones&#xa0;▸ Configuración&#xa0;▸ Secuencia de carga</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Carga de captura</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Está a punto de cargar la imagen en un destino externo. ¿Quiere continuar?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Pedir confirmación antes de cargar</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Tipo de cargador:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Secuencia de órdenes</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Subir imagen</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Construcción</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Usando:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation type="unfinished">Imagen de marca de agua</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished">Actualización</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation type="unfinished">Rotar la marca de agua</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation type="unfinished">Cuando esté activada, la marca de agua se añadirá con una rotación de 45°</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
